/* Project name:
     Led_Blinking 2.0 (The little bit more complex simple example)
 * Copyright:
     (c) 
 * Modified by:
      Stevan A. Milinkovic
      Union University, School of Computing
      Knez Mihailova 6, 11000 Belgrade, Serbia
      e-mail: smilinkovic@raf.edu.rs
 * Revision History:
       - initial release;
 * Description:
     "Hello world" example for the world of ARM MCUs using FreeRTOS;
 * Test configuration:
     Device:          STM32F107VC
                      http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/CD00220364.pdf
     Dev.Board:       EasyMx v7 for STM(R) ARM(R)
                      http://www.mikroe.com/eng/products/view/852/easymx-pro-v7-for-stm32/
                   eds
     Oscillator:      HSE-PLL, 72.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/eng/products/view/752/mikroc-pro-for-arm/
 * NOTES:
     - Turn ON PORTA, PORTB, PORTC, PORTD, PORTE at SW15 (board specific).
 */


#include "FreeRTOS.h"
#include "task.h"

#define ledSTACK_SIZE               configMINIMAL_STACK_SIZE
#define mainBLINKING_TASK_PRIORITY  ( tskIDLE_PRIORITY + 1 )
#define TaskDelay_ms(x)             vTaskDelay( x/portTICK_RATE_MS )


static portTASK_FUNCTION( vLedBlinkingTask, pvParameters ) {
  for (;;) {
    GPIOA_ODR = ~GPIOA_ODR; // Toggle PORTA
    GPIOB_ODR = ~GPIOB_ODR; // Toggle PORTB
    GPIOC_ODR = ~GPIOC_ODR; // Toggle PORTC
    GPIOD_ODR = ~GPIOD_ODR; // Toggle PORTD
    GPIOE_ODR = ~GPIOE_ODR; // Toggle PORTE
    TaskDelay_ms(100);
  }
}


void main(void ) {
  GPIO_Digital_Output(&GPIOA_BASE, _GPIO_PINMASK_ALL); // Set PORTA as digital output
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_ALL); // Set PORTB as digital output
  GPIO_Digital_Output(&GPIOC_BASE, _GPIO_PINMASK_ALL); // Set PORTC as digital output
  GPIO_Digital_Output(&GPIOD_BASE, _GPIO_PINMASK_ALL); // Set PORTD as digital output
  GPIO_Digital_Output(&GPIOE_BASE, _GPIO_PINMASK_ALL); // Set PORTE as digital output

  GPIOA_ODR = 0;
  GPIOB_ODR = 0;
  GPIOC_ODR = 0;
  GPIOD_ODR = 0;
  GPIOE_ODR = 0;

  xTaskCreate( vLedBlinkingTask,  ( signed char * ) "LED", ledSTACK_SIZE, NULL, mainBLINKING_TASK_PRIORITY, ( xTaskHandle * ) NULL );
  vTaskStartScheduler();
}